@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh::Ssh ;
-$Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.239';
+$Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.240';
 use Mouse ;
 use 5.10.1;
 extends "Config::Model::Backend::OpenSsh" ;
@@ -41,12 +41,11 @@ sub host {
 }
 
 sub forward {
-    my ($self,$root,$key,$args,$comment)  = @_;
+    my ($self, $root, $key, $args, $comment, $check)  = @_;
     $logger->debug("forward: $key @$args # $comment");
     $self->current_node = $root unless defined $self->current_node ;
 
     my $elt_name = $key =~ /local/i ? 'Localforward' : 'RemoteForward' ;
-    my $size = $self->current_node->fetch_element($key)->fetch_size;
 
     my $v6 = ($args->[1] =~ m![/\[\]]!) ? 1 : 0;
 
@@ -63,20 +62,22 @@ sub forward {
     my ($port,$bind_adr ) = reverse split $re,$args->[0] ;
     my ($host,$host_port) = split $re,$args->[1] ;
 
-    my $load_str = '';
-    $load_str .= "GatewayPorts=1 " if $bind_adr ;
-    my $note = $comment || '' ;
-    $note =~ s/"/\\"/g;
-    $note = qq!#"$note"! if $note ;
-    $load_str .= "$key:$size$note ";
+    my $fw_list = $self->current_node->fetch_element($key);
+    my $size = $fw_list->fetch_size;
+    # this creates a new node in the list
+    my $fw_obj = $fw_list->fetch_with_id($size);
 
-    $load_str .= 'ipv6=1 ' if $v6 ;
+    # $fw_obj->store_element_value( GatewayPorts => 1 ) if $bind_adr ;
+    $fw_obj->annotation($comment) if $comment;
 
-    $load_str .= "bind_address=$bind_adr " if defined $bind_adr ;
-    $load_str .= "port=$port host=$host hostport=$host_port";
+    $fw_obj->store_element_value( ipv6 => 1) if $v6 ;
+
+    $fw_obj->store_element_value( check => $check, name => 'bind_address', value => $bind_adr)
+        if defined $bind_adr ;
+    $fw_obj->store_element_value( check => $check, name => 'port', value => $port );
+    $fw_obj->store_element_value( check => $check, name => 'host', value => $host );
+    $fw_obj->store_element_value( check => $check, name => 'hostport', value => $host_port );
 
-    $logger->debug("load string $load_str") ;
-    $self->current_node -> load($load_str) ;
 }
 
 sub write_all_host_block {
@@ -145,7 +146,7 @@ Config::Model::Backend::OpenSsh::Ssh - Backend for ssh configuration files
 
 =head1 VERSION
 
-version 1.239
+version 1.240
 
 =head1 SYNOPSIS
 
